@@ -10,12 +10,14 @@ from RG.cPCA import *
 from RG.LDA import *
 from RG.PCA_ellipse import *
 from RG.ICA import *
+from RG.MCR import *
 
 
 from RG.colorspectra import *
 from RG.axaline import *
 from RG.lags import *
 from RG.DTW import *
+from RG.DTW_batch import *
 
 from RG.center import *
 from RG.autoscale import *
