@@ -2,7 +2,7 @@
 
 import numpy as np
 
-def center(X):
+def center(X, *args):
     '''
     
     Center: center data
@@ -13,6 +13,10 @@ def center(X):
         spectra
         n samples
         k variables
+    *args
+        optional inputs
+        mX [1 x k] 
+            mean of all variables - computed beforehand
     
     OUTPUT
     X_auto [n x k] 
@@ -22,8 +26,19 @@ def center(X):
     
     '''
     
+    varargin = args
+    n_params = len(varargin)
+
+    if n_params == 1:
+        mx = varargin[0]
+        mx = np.squeeze(mx)
+        
+    else:
+        mx = np.nanmean(X, axis=0)
+    
+    
     m,n = X.shape
-    mx = np.nanmean(X, axis=0)
+
     ax = (X - mx)
     
     mx = mx[np.newaxis]
